% ECOTRAN_StaticScenarios_GB_MammalAgg_01172015
% run and plot static scenarios
% by Jim Ruzicka
% calls:
%           f_read_EwE_csv_01122015
%           f_AggregateResults_EwE_01122015
%           ECOTRANuncertainty_01112015
%                   f_ECOfunction_01112015              returns a single ECOTRAN model for 1 "type" EwE model or 1 MonteCarlo EwE model
%                   f_RedistributeCannibalism           remove cannibalism terms on diagonal of matrix EwE_diet
%                   f_CalcPredationMatrix               for each producer, p, and consumer, c: ((b_pc * Q_c) / M2_p)) = the fraction of total predation on each producer, p, going to each consumer, c
%                   f_AggregateResults_ECOTRANS         (QQQ optional; usually turned off; not present in this code version)
%           f_E2E_MonteCarlo_09052013
%                   f_WebProductivityWLoss
%           f_WebProductivityWLoss
%           f_ScenarioGenerator_08302013
%                   f_WebProductivityWLoss
%           f_CompileScenarioResults_08192013
%           p_PlotScenarioResults_01172015
%                   myboxplot_2
% revision date: 1-17-2015





% *************************************************************************
% STEP 1: load & aggregate EwE results-------------------------------------
% step 1a: define model to work with
ReadFile_directory         = '/Users/ruzickaj/Documents/3_FoodWeb_models/11_GB/';
readFile                   = 'GBprs_FullRes_06062012.csv';
readFile                   = [ReadFile_directory readFile];

% step 1b: load EwE model from K-path (.csv format)
[dat]                      = f_read_EwE_csv_01122015(readFile);

% step 1c: aggregate model results & prep EwEResult for analysis
[EwEResult, PEDIGREE]      = f_AggregateResults_EwE_01122015(dat);





% *************************************************************************
% STEP 2: load Monte Carlo models------------------------------------------
% step 2a: Identify Monte Carlo method
% method 1: start with the one original ECOTRAN base model and generate a set of Monte Carlo E2E models of the ECOTRAN production matrix using a predefined CV (or defualt pedigree CV = 0.5)
% method 2: use prior generated Monte Carlo EwE models, convert to ECOTRAN E2E models, and run scenarios directly on EACH of these individually
%           (each matrix being its own base model and scenario model)
MonteCarlo_method = 2; % choose 1 or 2
use_MonteCarlo    = 'y'; % use MonteCarlo uncertainty esimates?

% step 2b: define MonteCarloSet  = name of Monte Carlo results with file directory (loads 'MonteCarloStore')
MonteCarloSet_FileDirectory = '/Users/ruzickaj/Documents/3_FoodWeb_models/11_GB/'; % NOTE laptop MAC directory format
MonteCarloSet               = 'GBprs_MCnorm_13-Jan-2015.mat'; % sampling interval = +/1 1 STD sampling (1 std in denominator)
MonteCarloSet               = [MonteCarloSet_FileDirectory MonteCarloSet];

% step 2c: load MonteCarloSet
if strcmp(use_MonteCarlo, 'y') && MonteCarlo_method == 2
    load(MonteCarloSet, 'MonteCarloStore')
%     [MonteCarlo_agg] = f_AggregateMonteCarlo_EwE_05182014(MonteCarloStore, dat); % aggregate MonteCarlo model
%     MonteCarloStore = MonteCarlo_agg;
else
    MonteCarloStore = [];
end





% *************************************************************************
% STEP 3: ECOTRAN conversion-----------------------------------------------
[ECOTRAN] = ECOTRANuncertainty_01112015(EwEResult, MonteCarloStore); % (QQQ error-check, dummy fisheries give clms of mostly NaNs)

% step 3a: read in ECOTRAN structure variables (so that no changes made to original values)
GroupType                                        = ECOTRAN.GroupType;
AggLabel                                         = ECOTRAN.AggLabel;
EnergyBudget_matrix                              = ECOTRAN.EnergyBudget_matrix;
% TransferEfficiency                               = ECOTRAN.TransferEfficiency; % gets redefined manually below

% step 3b: trim BA & EM rows (if they exist)
looky_BA                                         = find(GroupType == ECOTRAN.GroupTypeDef_BA);
looky_EM                                         = find(GroupType == ECOTRAN.GroupTypeDef_EM);
GroupType([looky_EM looky_BA])                   = []; % trim BA & EM from GroupType
AggLabel([looky_EM looky_BA])                    = []; % trim BA & EM from AggLabel
[E2E_rows, E2E_clms, E2E_layers]                 = size(EnergyBudget_matrix);

% step 3c: find detritus, and nutrients by row address in EnergyBudget_matrix (if they exist)
looky_NUTRIENTS                                  = find(floor(GroupType) == ECOTRAN.GroupTypeDef_ANYNitroNutr);
looky_DETRITUS                                   = find(floor(GroupType) == ECOTRAN.GroupTypeDef_ANYDetritus);
looky_BnthDETRITUS                               = find(GroupType        == ECOTRAN.GroupTypeDef_terminalBnthDetr);
looky_plgcNH4                                    = find(GroupType        == ECOTRAN.GroupTypeDef_plgcNH4);

% step 3e: matrix addresses of GBprs_MammalAgg groups (for easier plotting)
% NOTE: these must be entered manually for each new model
NO3_rowclm          = 1;
PlgcNH4_rowclm      = 2;
BnthNH4_rowclm      = 3;
SmlPhyto_rowclm     = 4;
LargePhyto_rowclm   = 5;
MicroZ_rowclm       = 6;
MesoZ_rowclm        = 7;
MacroZ_rowclm       = 8;
Jelly_rowclm        = 9;
PlankFish_rowclm	= 10;
PiscFish_rowclm     = 11;
BenthFish_rowclm	= 12;
JuvFish_rowclm      = 13;
MeioBnthos_rowclm   = 14;
DepFBen_rowclm      = 15;
CarnBen_rowclm      = 16;
SuspFBen_rowclm     = 17;
SeaBird_rowclm      = 18;
BalWhal_rowclm      = 19;
Odontocete_rowclm   = 20;
Fishery_rowclm      = 21; % <<--note that fisheries come before terminal detritus
PlgcDetr_rowclm     = 22;
BnthcDetr_rowclm	= 23; % this is a dummy group





% % *************************************************************************
% % STEP OPTIONAL: plotting of MonteCarlo parameter distributions
% target_grp = [ Benthicdecapod_rowclm SmallInshoreDemersals_rowclm GentooPenguins_rowclm Sub_AntarcticFurSeals_rowclm];
% target_grp = target_grp - 3; % subtract 3 because of nutrients
% target_parameter = 'PB'; % choose parameter to plot: 'biomass', 'production', 'PB', 'QB', 'PQ', 'AE', 'Landings', 'Discards' (QQQ later to add BA, EM, diet, consumption)
% 
% if strcmp(use_MonteCarlo, 'y') && MonteCarlo_method == 2
%     
%     p_MonteCarlo_EwEDistribution_09062013(EwEResult, PEDIGREE, MonteCarloStore, target_grp, target_parameter)
% 
% end





% *************************************************************************
% STEP 4: TransferEfficiency-----------------------------------------------
% SET MANUALLY: TransferEfficiency = 1 for all groups because we are
%           working with the consumption budget matrix that tracks the fate of ALL consumption (not just predation)
%           system losses (groups where TransferEfficiency < 1 include benthic detritus, fishery, (others?)
TransferEfficiency                        = ones(E2E_layers, E2E_clms); % re-initialize as rows of horizontal vector of 1s
TransferEfficiency(:, looky_BnthDETRITUS) = 0.1; % defualt TE for benthic detritus





% *************************************************************************
% STEP 5: define production loss fractions---------------------------------
% (FFF in future, might use vector read in from .csv file; but for now, this is all handled here)
% LX                   = 0; % NOTE: set to 0 to ignore physical losses; set to 1 for the default relative upwelling index (1 is used for the average yearly relative upwelling index)
LX_base                       = ones(1, E2E_clms);
ProductionLossScaler_base     = zeros(1, E2E_clms); % initialize
PhysicalLossFraction_base     = ProductionLossScaler_base .* LX_base;

LX_scenario                   = ones(1, E2E_clms);
ProductionLossScaler_scenario = zeros(1, E2E_clms); % initialize
PhysicalLossFraction_scenario = ProductionLossScaler_scenario .* LX_scenario;





% *************************************************************************
% STEP 6: initialize InputProductionVector---------------------------------
% NOTE: here you can run a scenario with an alternate driver
InputProductionVector_base                 = zeros(1, E2E_clms); % initialize InputProductionVector_base
InputProductionVector_scenario             = zeros(1, E2E_clms); % initialize InputProductionVector_scenario

% FOR GBprs_MammalAgg <<-----------------------------------------
InputOpenOceanSmlPhytop_base = 9.597933 * 123; % production rate = biomass * P/B = t/km2/y
InputOpenOceanLrgPhytop_base = 10.16146 * 123; % production rate = biomass * P/B = t/km2/y

InputProductionVector_base(SmlPhyto_rowclm)   = InputOpenOceanSmlPhytop_base;
InputProductionVector_base(LargePhyto_rowclm) = InputOpenOceanLrgPhytop_base;

InputOpenOceanSmlPhytop_scenario = 9.597933 * 123; % production rate = biomass * P/B = t/km2/y
InputOpenOceanLrgPhytop_scenario = 10.16146 * 123; % production rate = biomass * P/B = t/km2/y

InputProductionVector_scenario(SmlPhyto_rowclm)   = InputOpenOceanSmlPhytop_scenario;
InputProductionVector_scenario(LargePhyto_rowclm) = InputOpenOceanLrgPhytop_scenario;



% step 6c: evaluate type of driver (nutrient vs living group)
% NOTE: THIS IS NEEDED IF DRIVEN BY ANYTHING OTHER THAN NO3
TestInput_base                      = InputProductionVector_base;
TestInput_scenario                  = InputProductionVector_scenario;
TestInput_base(looky_NUTRIENTS)     = [];
TestInput_scenario(looky_NUTRIENTS) = [];
if max(TestInput_base > 0 | TestInput_scenario > 0); 
    disp('WARNING: non-NO3 driver. Be sure to deactivate nutrient recycling; set Nutrient columns in production matrix to 0');
    EnergyBudget_matrix(:, looky_NUTRIENTS, :) = 0; % shut off recycling
    % NOTE: this automatic switch assumes that both the base and the scenario are using non-nutrient drivers
    % Will need to add a more sophisticated switch to allow a nutrient driver base and a non-nutrient driver scenario (or vice-versa)
else
    disp('WARNING: NO3 driver. Be sure to keep nutrient recycling ACTIVATED'); 
end





% *************************************************************************
% STEP 7: Monte Carlo------------------------------------------------------
if MonteCarlo_method == 1
    
    % method 1: start with the one original ECOTRAN base model and generate a set of Monte Carlo E2E models 
    %           of the ECOTRAN production matrix using a predefined CV (or defualt pedigree CV = 0.5)
    MonteCarloConditions.num_trials                 = 1000; % number of trials to run
    MonteCarloConditions.pedigree                   = []; % set CV about which to sample cells in base_EnergyBudget_matrix; if pedigree = [], default is CV = 0.5
    MonteCarloConditions.TransferEfficiency         = TransferEfficiency(1, :); % take just the first entry (in case you have loaded the MonteCarloStore models that are used with MonteCarlo_method = 2)
    MonteCarloConditions.PhysicalLossFraction       = PhysicalLossFraction_base(1, :); 
    MonteCarloConditions.InputProductionVector      = InputProductionVector_base(1, :);
    MonteCarloConditions.EnergyBudget_matrix        = EnergyBudget_matrix;
    [Production_MonteCarlo EnergyBudget_MonteCarlo] = f_E2E_MonteCarlo_09052013(MonteCarloConditions);
    Production_base                                 = Production_MonteCarlo; % base productivity of each Monte Carlo array; (g WWT m^(-2) d^(-1))
    EnergyBudget_base                               = EnergyBudget_MonteCarlo;
    
elseif MonteCarlo_method == 2
    
    % method 2: use prior generated Monte Carlo EwE models, convert to ECOTRAN E2E models, and run scenarios directly on EACH of these individually
    %           (each matrix being its own base model and scenario model)
    for MonteCarlo_loop = 1:E2E_layers
        current_EnergyBudget_matrix               = EnergyBudget_matrix(:, :, MonteCarlo_loop);
        current_TransferEfficiency                = TransferEfficiency(MonteCarlo_loop, :);
        Production_MonteCarlo(:, MonteCarlo_loop) = f_WebProductivityWLoss(current_TransferEfficiency, current_EnergyBudget_matrix, InputProductionVector_base, PhysicalLossFraction_base);
    end % (MonteCarlo_loop)
    Production_base                               = Production_MonteCarlo; % base production rates calculated using each MonteCarlo EnergyBudget_matrix; (g WWT m^(-2) d^(-1))
    EnergyBudget_base                             = EnergyBudget_matrix;
    
end % (choose MonteCarlo_method)



% % *************************************************************************
% % STEP 8: production fate break-down---------------------------------------
% %         provide the detailed flow of production through the EnergyBudget_matrix
% %         production of each group (rows) originating from each producer groups (clms)
% ProductionSourceRates = f_DetailedProductionBreakdown(EnergyBudget_matrix, Production_MonteCarlo); % (3D matrix: num_groups X num_groups X num_trials)
% Production_plgcNH4_mean = mean(ProductionSourceRates(looky_plgcNH4, :, :), 3);
% Production_plgcNH4_std  = std(ProductionSourceRates(looky_plgcNH4, :, :), 0, 3);
% 
% Production_mean = mean(Production_base, 2);
% Production_std  = std(Production_base, 0, 2);
% Production_mean = Production_mean';
% Production_std = Production_std';





% *************************************************************************
% STEP 6: SCENARIOS--------------------------------------------------------

% 1) MAMMAL scenario: baleen X5 (p = ALL) ------------------------------------
ScenarioConditions.trgt_producer           = 1:E2E_clms; % column number(s) of producer group(s)
ScenarioConditions.ScaleFactor             = 5; % value > 1 means increase flow to modify_consumer (and reduced flow to offset_consumer); < 1 means decrease flow to modify_consumer; 
%                                                   NOTE: keep ScaleFactor >= 0 (negative value makes no sense)
ScenarioConditions.modify_consumer         = [BalWhal_rowclm];
ScenarioConditions.offset_consumer         = [1:E2E_clms];
ScenarioConditions.offset_consumer([looky_NUTRIENTS; looky_DETRITUS]) = []; % (assume no change to detritus or to nutrients; --YOU ARE FREE TO CHANGE THIS ASSUMPTION--!!!)
ScenarioConditions.EnergyBudget_base       = EnergyBudget_base; % this is MonteCarlo set of EnergyBudget_matrix models
ScenarioConditions.TransferEfficiency      = TransferEfficiency;
ScenarioConditions.InputProductionVector   = InputProductionVector_base; % <<<---NOTE base input production driver rates
ScenarioConditions.PhysicalLossFraction    = PhysicalLossFraction_base; % <<<---NOTE base advection rates
ScenarioConditions.force_offset            = 'n'; % ('y' means to force offset consumer fractions evenly, even if original value is 0; 'n' means to distribute proportionally to original values


% 2) Plank Fish scenario: Plank Fish X2 (p = ALL) -----------------------------------
ScenarioConditions.trgt_producer           = 1:E2E_clms; % column number(s) of producer group(s)
ScenarioConditions.ScaleFactor             = 2; % value > 1 means increase flow to modify_consumer (and reduced flow to offset_consumer); < 1 means decrease flow to modify_consumer; 
%                                                   NOTE: keep ScaleFactor >= 0 (negative value makes no sense)
ScenarioConditions.modify_consumer         = [PlankFish_rowclm];
ScenarioConditions.offset_consumer         = [1:E2E_clms];
ScenarioConditions.offset_consumer([looky_NUTRIENTS; looky_DETRITUS]) = []; % (assume no change to detritus or to nutrients; --YOU ARE FREE TO CHANGE THIS ASSUMPTION--!!!)
ScenarioConditions.EnergyBudget_base       = EnergyBudget_base; % this is MonteCarlo set of EnergyBudget_matrix models
ScenarioConditions.TransferEfficiency      = TransferEfficiency;
ScenarioConditions.InputProductionVector   = InputProductionVector_base; % <<<---NOTE base input production driver rates
ScenarioConditions.PhysicalLossFraction    = PhysicalLossFraction_base; % <<<---NOTE base advection rates
ScenarioConditions.force_offset            = 'n'; % ('y' means to force offset consumer fractions evenly, even if original value is 0; 'n' means to distribute proportionally to original values


% 4) ALL Jellyfish scenario: ALL Jellyfish X2 (p = ALL)-------------
ScenarioConditions.trgt_producer           = 1:E2E_clms; % column number(s) of producer group(s)
ScenarioConditions.ScaleFactor             = 2; % value > 1 means increase flow to modify_consumer (and reduced flow to offset_consumer); < 1 means decrease flow to modify_consumer; 
%                                                   NOTE: keep ScaleFactor >= 0 (negative value makes no sense)
ScenarioConditions.modify_consumer         = [Jelly_rowclm];
ScenarioConditions.offset_consumer         = [1:E2E_clms];
ScenarioConditions.offset_consumer([looky_NUTRIENTS; looky_DETRITUS]) = []; % (assume no change to detritus or to nutrients; --YOU ARE FREE TO CHANGE THIS ASSUMPTION--!!!)
ScenarioConditions.EnergyBudget_base       = EnergyBudget_base; % this is MonteCarlo set of EnergyBudget_matrix models
ScenarioConditions.TransferEfficiency      = TransferEfficiency;
ScenarioConditions.InputProductionVector   = InputProductionVector_base; % <<<---NOTE base input production driver rates
ScenarioConditions.PhysicalLossFraction    = PhysicalLossFraction_base; % <<<---NOTE base advection rates
ScenarioConditions.force_offset            = 'n'; % ('y' means to force offset consumer fractions evenly, even if original value is 0; 'n' means to distribute proportionally to original values





% step 6b: generate scenario model(s) -------------------------------------
[EnergyBudget_scenario Production_scenario BuildGroup max_ScaleFactor] = f_ScenarioGenerator_08302013(ScenarioConditions, ECOTRAN);

% step 6c: compile scenario results (scenario_FractionalChange = change relative to un-altered model; scenario_RatioChange = altered to un-altered model ratio)
[FractionalChange, RatioChange, scenario_ResultsCompiled] = f_CompileScenarioResults_08192013(Production_base, Production_scenario, max_ScaleFactor);
% scenario_ResultsCompiled:
%       clm 1: FractionalChange_mean
%       clm 2: FractionalChange_std
%       clm 3: RatioChange_mean 
%       clm 4: RatioChange_std
%       clm 5: Production_scenario_mean 
%       clm 6: Production_scenario_std 
%       clm 7: Production_base_mean 
%       clm 8: Production_base_std

% step 6d: plot scenario results 
%       scenario_FractionalChange: change relative to un-altered model
%       scenario_RatioChange: altered to un-altered model ratio)
%       choose which to plot within code p_PlotScenarioResults
target_groups = [PlankFish_rowclm; PiscFish_rowclm; BenthFish_rowclm; ...
    SeaBird_rowclm; BalWhal_rowclm; Odontocete_rowclm; ...
    CarnBen_rowclm; Fishery_rowclm]; % select groups to plot along x-axis; set to empty ([]) to plot all

AggLabel = {
'NO_{3}'
'pelagic NH_{4}'
'benthic NH_{4}'
'small phytoplankton'
'large phytoplankton'
'micro-zooplankton'
'meso-zooplankton'
'macro-zooplankton'
'jellyfish'
'planktivorous fish'
'piscivorous fish'
'benthivorous fish'
'juvenile fish'
'meiobenthos'
'deposit feeding benthos'
'carnivorous benthos'
'suspension feeding benthos'
'seabirds'
'baleen whales'
'odontocetes'
'fisheries'
'pelagic detritus'
'benthic detritus'};

y_axis        = [0 2.5]; % define y-axis in plots
% p_PlotScenarioResults_06052014(FractionalChange, RatioChange, AggLabel, BuildGroup, target_groups, y_axis)
p_PlotScenarioResults_01172015(FractionalChange, RatioChange, AggLabel, BuildGroup, target_groups, 'RatioChange', y_axis)


% end m-file***************************************************************